@@ -214,7 +214,7 @@ appendToTable <- function(tbl, data) {
   if (!inherits(tbl, "tbl_dbi")) {
     abort("First argument must be an Andromeda table")
   }
-    
+  
   # This now gives an error. How can we check that a table is not a query result? 
   # Perhaps using as.character(dbplyr::sql_render(tbl))
   # if (!inherits(tbl$ops, "op_base_remote")) {
@@ -245,7 +245,13 @@ appendToTable <- function(tbl, data) {
                              append = TRUE)
       }
       batchApply(data, doBatchedAppend)
+      # Could have lots of data in buffers. We don't want to hog the memory, so free up in source
+      # Andromeda:
+      Andromeda::flushAndromeda(dbplyr::remote_con(data), evictCache = TRUE)      
     }
+    # Could have lots of data in buffers. We don't want to hog the memory, so free up in target
+    # Andromeda:
+    Andromeda::flushAndromeda(connection, evictCache = TRUE)
   }
   invisible(NULL)
 }
@@ -385,6 +391,7 @@ restorePosixct <- function(x) {
 #' Flush changes to disk
 #'
 #' @param andromeda An [`Andromeda`] object.
+#' @param evictCache If TRUE, will also evict the cache to free up memory.
 #'
 #' @description
 #' Flush all changes to disk. This only affects the data in the Andromeda temp folder. 
@@ -405,6 +412,16 @@ restorePosixct <- function(x) {
 #' close(andr)
 #' 
 #' @export
-flushAndromeda <- function(andromeda) {
-  DBI::dbExecute(andromeda, "CHECKPOINT;")
+flushAndromeda <- function(andromeda, evictCache = TRUE) {
+  if (isAndromeda(andromeda())) {
+    DBI::dbExecute(andromeda, "CHECKPOINT;")
+    
+    if (evictCache) {
+      # DuckDB likes to keep a cache as big as the memory limit. To free this up, we temporarily 
+      # reduce the memory limit, forcing the cache to be dropped:
+      currentLimit <- DBI::dbGetQuery(andromeda, "SELECT current_setting('memory_limit');")
+      DBI::dbExecute(andromeda, "SET memory_limit = '128MB';")
+      DBI::dbExecute(andromeda, sprintf("SET memory_limit = '%s';", currentLimit))
+    }
+  }
 }
